@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Play the tabla!
 
-our $VERSION = '0.0301';
+our $VERSION = '0.0400';
 
 use Moo;
 use File::ShareDir qw(dist_dir);
@@ -26,65 +26,33 @@ sub _build_soundfont {
 }
 
 
+has patches => (
+    is      => 'ro',
+    default => sub {
+        {
+            dhun => [qw(67 80)],
+            ge   => [qw(65 66 76)],
+            ke   => [qw(64 77 79)],
+            na   => [qw(78 81)],
+            ta   => [qw(71 75 85 88)],
+            ti   => [qw(61 68 70 72 82 86)],
+            tin  => [qw(60 63 83 87)],
+            tun  => [qw(73)],
+        }
+    },
+);
+
+
 sub BUILD {
     my ($self, $args) = @_;
     $self->set_channel(0);
 }
 
 
-sub dhun {
-    my ($self, $dura, $index) = @_;
-    my @patches = qw(67 80);
-    my $patch = _patch_index(\@patches, $index);
-    $self->_strike($dura, $patch);
-}
-
-sub ge {
-    my ($self, $dura, $index) = @_;
-    my @patches = qw(65 66 76);
-    my $patch = _patch_index(\@patches, $index);
-    $self->_strike($dura, $patch);
-}
-
-sub ke {
-    my ($self, $dura, $index) = @_;
-    my @patches = qw(64 77 79);
-    my $patch = _patch_index(\@patches, $index);
-    $self->_strike($dura, $patch);
-}
-
-sub na {
-    my ($self, $dura, $index) = @_;
-    my @patches = qw(78 81);
-    my $patch = _patch_index(\@patches, $index);
-    $self->_strike($dura, $patch);
-}
-
-sub ta {
-    my ($self, $dura, $index) = @_;
-    my @patches = qw(71 75 85 88);
-    my $patch = _patch_index(\@patches, $index);
-    $self->_strike($dura, $patch);
-}
-
-sub ti {
-    my ($self, $dura, $index) = @_;
-    my @patches = qw(61 68 70 72 82 86);
-    my $patch = _patch_index(\@patches, $index);
-    $self->_strike($dura, $patch);
-}
-
-sub tin {
-    my ($self, $dura, $index) = @_;
-    my @patches = qw(60 63 83 87);
-    my $patch = _patch_index(\@patches, $index);
-    $self->_strike($dura, $patch);
-}
-
-sub tun {
-    my ($self, $dura, $index) = @_;
-    my @patches = qw(73);
-    my $patch = _patch_index(\@patches, $index);
+sub strike {
+    my ($self, $bol, $dura, $index) = @_;
+    my $patches = $self->patches->{$bol};
+    my $patch = _patch_index($patches, $index);
     $self->_strike($dura, $patch);
 }
 
@@ -115,7 +83,7 @@ Music::Percussion::Tabla - Play the tabla!
 
 =head1 VERSION
 
-version 0.0301
+version 0.0400
 
 =head1 SYNOPSIS
 
@@ -128,10 +96,10 @@ version 0.0301
   say $t->soundfont;
 
   for my $i (1 .. 3) {
-    $t->ta($t->eighth);
-    $t->ta($t->eighth);
-    $t->tun;
-    $t->ge;
+    $t->strike('ta', $t->eighth);
+    $t->strike('ta', $t->eighth);
+    $t->strike('tun');
+    $t->strike('ge');
     $t->rest($t->quarter);
   }
 
@@ -148,39 +116,39 @@ Here are my "non-tabla player" descriptions of the sounds:
 
    # MIDI Bol  - Description
   ...
-   1 60   tin  - ringing mid
-   2 61   ti   - muted low
-   3 62   ?    - slap
-   4 63   tin  - ringing mid slap
-   5 64   ke   - low knock
-   6 65   ge   - muted ringing low
-   7 66   ge   - lower
-   8 67   dhun - low-up
-   9 68   ti   - muted slap
-  10 69   ?    - ringing low
-  11 70   ti   - flam slap
-  12 71   ta   - loud tap
-  13 72   ti   - lowest mute
-  14 73   tun  - ringing low
-  15 74   ?    - muted low
-  16 75   ta   - loud tap double
-  17 76   ge   - high-low
-  18 77   ke   - high slap
-  19 78   na   - tap
-  20 79   ?    - high knock
-  21 80   dhun - short low-up
-  22 81   na   - mid tap
-  23 82   ti   - muted tap
-  24 83   tin  - mid
-  25 84   ?    - muted
-  26 85   ta   - loud mid double
-  27 86   ti   - slightly more muted
-  28 87   tin  - low mid
-  29 88   ta   - ringing mid
+   1  60  tin  - ringing mid
+   2  61  ti   - muted low
+   3  62  ?    - slap
+   4  63  tin  - ringing mid slap
+   5  64  ke   - low knock
+   6  65  ge   - muted ringing low
+   7  66  ge   - lower
+   8  67  dhun - low-up
+   9  68  ti   - muted slap
+  10  69  ?    - ringing low
+  11  70  ti   - flam slap
+  12  71  ta   - loud tap
+  13  72  ti   - lowest mute
+  14  73  tun  - ringing low
+  15  74  ?    - muted low
+  16  75  ta   - loud tap double
+  17  76  ge   - high-low
+  18  77  ke   - high slap
+  19  78  na   - tap
+  20  79  ?    - high knock
+  21  80  dhun - short low-up
+  22  81  na   - mid tap
+  23  82  ti   - muted tap
+  24  83  tin  - mid
+  25  84  ?    - muted
+  26  85  ta   - loud mid double
+  27  86  ti   - slightly more muted
+  28  87  tin  - low mid
+  29  88  ta   - ringing mid
   ...
 
-To play patches by number, do this to add to the C<84>th MIDInum entry
-score:
+To play patches by number (for the unknown bols, for instance), do
+this to add to the C<84>th MIDInum entry score:
 
   $tabla->note($tabla->eighth, 84);
 
@@ -198,6 +166,21 @@ The file location, where the tabla soundfont resides.
 
 Default: F<dist_dir()/Tabla.sf2>
 
+=head2 patches
+
+  $patches = $tabla->patches;
+
+Default bol patches:
+
+  dhun: 67 80
+  ge:   65 66 76
+  ke:   64 77 79
+  na:   78 81
+  ta:   71 75 85 88
+  ti:   61 68 70 72 82 86
+  tin:  60 63 83 87
+  tun:  73
+
 =head1 METHODS
 
 =head2 new
@@ -209,13 +192,17 @@ constructor attributes of L<MIDI::Drummer::Tiny>.
 
 =for Pod::Coverage BUILD
 
-=head2 dhun, ge, ke, na, ta, ti, tin, tun
+=head2 strike
 
-  $tabla->dhun; # & etc methods
-  $tabla->dhun($duration);
-  $tabla->dhun($duration, $index);
+  $tabla->strike('dhun');
+  $tabla->strike('ge', $duration);
+  $tabla->strike('ti', $duration, $index);
 
-Where the B<duration> is a note length like C<$tabla-E<gt>eighth> (or
+Bols:
+
+  dhun, ge, ke, na, ta, ti, tin, tun
+
+The B<duration> is a note length like C<$tabla-E<gt>eighth> (or
 C<'en'> in MIDI-Perl notation).
 
 Each bol can be 1 or more patch numbers. For bols with more than one
@@ -224,19 +211,10 @@ B<index> of C<-1> will play one of the patches at random. You can of
 course, also call the method with a known patch B<index> to get only
 that patch.
 
-Default patches:
-
-  dhun: 67 80
-  ge:   65 66 76
-  ke:   64 77 79
-  na:   78 81
-  ta:   71 75 85 88
-  ti:   61 68 70 72 82 86
-  tin:  60 63 83 87
-  tun:  73
-
 =head1 SEE ALSO
 
+The F<t/01-methods.t> and F<eg/*> programs in this distribution.
+
 L<Moo>
 
 L<File::ShareDir>
